@@ -2,9 +2,9 @@
 /*! \file cvc4.h
  ** \verbatim
  ** Top contributors (to current version):
- **   Morgan Deters, Tim King
+ **   Mathias Preiner
  ** This file is part of the CVC4 project.
- ** Copyright (c) 2009-2018 by the authors listed in the file AUTHORS
+ ** Copyright (c) 2009-2020 by the authors listed in the file AUTHORS
  ** in the top-level source directory) and their institutional affiliations.
  ** All rights reserved.  See the file COPYING in the top-level source
  ** directory for licensing information.\endverbatim
@@ -15,8 +15,8 @@
  ** most-commonly used CVC4 public-facing class interfaces.
  **/
 
-#ifndef __CVC4__CVC4_H
-#define __CVC4__CVC4_H
+#ifndef CVC4__CVC4_H
+#define CVC4__CVC4_H
 
 #include <cvc4/base/configuration.h>
 #include <cvc4/base/exception.h>
@@ -31,4 +31,4 @@
 #include <cvc4/util/integer.h>
 #include <cvc4/util/rational.h>
 
-#endif /* __CVC4__CVC4_H */
+#endif /* CVC4__CVC4_H */
