@@ -2,9 +2,9 @@
 /*! \file array_store_all.h
  ** \verbatim
  ** Top contributors (to current version):
- **   Tim King, Morgan Deters
+ **   Tim King, Morgan Deters, Mathias Preiner
  ** This file is part of the CVC4 project.
- ** Copyright (c) 2009-2019 by the authors listed in the file AUTHORS
+ ** Copyright (c) 2009-2020 by the authors listed in the file AUTHORS
  ** in the top-level source directory) and their institutional affiliations.
  ** All rights reserved.  See the file COPYING in the top-level source
  ** directory for licensing information.\endverbatim
@@ -18,8 +18,8 @@
 
 #include <cvc4/cvc4_public.h>
 
-#ifndef __CVC4__ARRAY_STORE_ALL_H
-#define __CVC4__ARRAY_STORE_ALL_H
+#ifndef CVC4__ARRAY_STORE_ALL_H
+#define CVC4__ARRAY_STORE_ALL_H
 
 #include <iosfwd>
 #include <memory>
@@ -72,4 +72,4 @@ struct CVC4_PUBLIC ArrayStoreAllHashFunction {
 
 }  // namespace CVC4
 
-#endif /* __CVC4__ARRAY_STORE_ALL_H */
+#endif /* CVC4__ARRAY_STORE_ALL_H */
